@@ -1,7 +1,7 @@
 // XGParam.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -528,7 +528,7 @@ class XGRpnParamMap : public QHash<XGRpnParamKey, XGParam *> {};
 // class XGParamMaster - XG Parameter master state database.
 //
 
-class XGParamMasterMap : public QHash<XGParamKey, XGParam *>
+class XGParamMasterMap : public QMultiHash<XGParamKey, XGParam *>
 {
 public:
 
