@@ -1,7 +1,7 @@
 // qxgeditMainForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -33,6 +33,7 @@
 #include "qxgeditCombo.h"
 
 #include "qxgeditOptionsForm.h"
+#include "qxgeditPaletteForm.h"
 
 #include <QApplication>
 #include <QMessageBox>
@@ -100,9 +101,8 @@ static void qxgedit_sigterm_handler ( int /* signo */ )
 qxgeditMainForm *qxgeditMainForm::g_pMainForm = nullptr;
 
 // Constructor.
-qxgeditMainForm::qxgeditMainForm (
-	QWidget *pParent, Qt::WindowFlags wflags )
-	: QMainWindow(pParent, wflags)
+qxgeditMainForm::qxgeditMainForm ( QWidget *pParent )
+	: QMainWindow(pParent)
 {
 	// Setup UI struct...
 	m_ui.setupUi(this);
@@ -1836,47 +1836,49 @@ void qxgeditMainForm::viewOptions (void)
 		return;
 
 	// Load the current setup settings.
-	const bool bOldCompletePath   = m_pOptions->bCompletePath;
-	const int  iOldMaxRecentFiles = m_pOptions->iMaxRecentFiles;
-	const int  iOldBaseFontSize   = m_pOptions->iBaseFontSize;
-	const QString sOldStyleTheme  = m_pOptions->sStyleTheme;
+	const bool    bOldCompletePath   = m_pOptions->bCompletePath;
+	const int     iOldMaxRecentFiles = m_pOptions->iMaxRecentFiles;
+	const int     iOldBaseFontSize   = m_pOptions->iBaseFontSize;
+	const QString sOldStyleTheme     = m_pOptions->sStyleTheme;
+	const QString sOldColorTheme     = m_pOptions->sColorTheme;
 	// Load the current setup settings.
 	qxgeditOptionsForm optionsForm(this);
 	optionsForm.setOptions(m_pOptions);
 	if (optionsForm.exec()) {
-		enum { RestartSession = 1, RestartProgram = 2, RestartAny = 3 };
-		// Check wheather something immediate has changed.
+		// Check whether restart is needed or whether
+		// custom options maybe set up immediately...
 		int iNeedRestart = 0;
-		if (sOldStyleTheme != m_pOptions->sStyleTheme) {
+		if (m_pOptions->sStyleTheme != sOldStyleTheme) {
 			if (m_pOptions->sStyleTheme.isEmpty()) {
-				iNeedRestart |= RestartProgram;
+				++iNeedRestart;
 			} else {
 				QApplication::setStyle(
 					QStyleFactory::create(m_pOptions->sStyleTheme));
 			}
 		}
+		if (m_pOptions->sColorTheme != sOldColorTheme) {
+			if (m_pOptions->sColorTheme.isEmpty()) {
+				++iNeedRestart;
+			} else {
+				QPalette pal;
+				if (qxgeditPaletteForm::namedPalette(
+						&m_pOptions->settings(), m_pOptions->sColorTheme, pal))
+					QApplication::setPalette(pal);
+			}
+		}
+		// Show restart message if needed...
 		if (iOldBaseFontSize != m_pOptions->iBaseFontSize)
-			iNeedRestart |= RestartProgram;
+			++iNeedRestart;
 		if (( bOldCompletePath && !m_pOptions->bCompletePath) ||
 			(!bOldCompletePath &&  m_pOptions->bCompletePath) ||
 			(iOldMaxRecentFiles != m_pOptions->iMaxRecentFiles))
 			updateRecentFilesMenu();
-		// Warn if something will be only effective on next time.
-		if (iNeedRestart & RestartAny) {
-			QString sNeedRestart;
-			if (iNeedRestart & RestartSession)
-				sNeedRestart += tr("session");
-			if (iNeedRestart & RestartProgram) {
-				if (!sNeedRestart.isEmpty())
-					sNeedRestart += tr(" or ");
-				sNeedRestart += tr("program");
-			}
-			// Show restart needed message...
+		// Show restart needed message...
+		if (iNeedRestart > 0) {
 			QMessageBox::information(this,
 				tr("Information"),
 				tr("Some settings may be only effective\n"
-				"next time you start this %1.")
-				.arg(sNeedRestart));
+				"next time you start this program."));
 		}
 	}
 
