@@ -1,7 +1,7 @@
 // qxgeditMainForm.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -45,7 +45,7 @@ class qxgeditMainForm : public QMainWindow
 public:
 
 	// Constructor.
-	qxgeditMainForm(QWidget *pParent = 0, Qt::WindowFlags wflags = 0);
+	qxgeditMainForm(QWidget *pParent = nullptr);
 	// Destructor.
 	~qxgeditMainForm();
 
