@@ -1,7 +1,7 @@
 // qxgeditOptions.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -26,7 +26,10 @@
 #include <QTextStream>
 
 #include <QApplication>
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QDesktopWidget>
+#endif
 
 
 //-------------------------------------------------------------------------
@@ -256,8 +259,10 @@ void qxgeditOptions::loadWidgetGeometry ( QWidget *pWidget, bool bVisible )
 			QWidget *pParent = pWidget->parentWidget();
 			if (pParent)
 				pParent = pParent->window();
+		#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 			if (pParent == nullptr)
 				pParent = QApplication::desktop();
+		#endif
 			if (pParent) {
 				QRect wrect(pWidget->geometry());
 				wrect.moveCenter(pParent->geometry().center());
